@@ -32,18 +32,29 @@ async def get_owner(client: TonlibClient, addr: str):
     return a.to_string()
 
 
-def get_items(client: TonlibClient, addresses: list, filename_with_nft_metadata=None, max_requests: int = 1000):
+def get_items(client: list[TonlibClient] or TonlibClient, addresses: list, filename_with_nft_metadata=None, max_requests: int = 1000):
     if filename_with_nft_metadata and 'json' not in filename_with_nft_metadata:
         raise Exception('Only .json files are expected')
     elif filename_with_nft_metadata:
         with open(filename_with_nft_metadata, 'r') as j:
             items = json.loads(j.read())
     nft_items = []
+
+    if isinstance(client, list):
+        pass
+    else:
+        client = [client]
+
+    d = 0
+
     for i in range(ceil(len(addresses) / max_requests)):
         tasks = []
         for addr in addresses[i * max_requests:min(len(addresses), max_requests * (i + 1))]:
-            tasks.append(get_item(client, addr, nft_items, items))
+            tasks.append(get_item(client[d % len(client)], addr, nft_items, items))
+            print(d % len(client))
+            d += 1
         asyncio.get_event_loop().run_until_complete(asyncio.gather(*tasks))
+        print('DONE')
     if len(nft_items) < len(addresses):
         raise Exception('SCANNED NOT ALL ITEMS')
     return {"nft_items": nft_items}
